Module stack

Stack Configuration

The stack module contains the core Config struct which is responsible for holding the configuration of the OP stack.

Example

use std::path::PathBuf;
use op_config::Config;

let config = Config::default();
assert_eq!(config.artifacts, PathBuf::from(Config::STACK_DIR_NAME));

Structs

Config
OP Stack Configuration

Constants

DEPLOYER_PRIVATE_KEY
Testing deployer private key.
L1_PORT
L1 node port.
L1_URL
L1 node url.
L2_PORT
L2 node port.
L2_URL
L2 node url.
ROLLUP_PORT
Rollup node port.
ROLLUP_URL
Rollup node url.