Struct Config

pub struct Config<'a> {
Show 17 fields pub profile: Profile, pub artifacts: PathBuf, pub monorepo: MonorepoConfig, pub l1_client: L1Client, pub l2_client: L2Client, pub rollup_client: RollupClient, pub l1_client_url: Option<String>, pub l1_client_port: Option<u16>, pub l2_client_url: Option<String>, pub l2_client_port: Option<u16>, pub rollup_client_url: Option<String>, pub rollup_client_port: Option<u16>, pub deployer: Option<String>, pub challenger: ChallengerAgent, pub enable_sequencing: bool, pub enable_fault_proofs: bool, pub eth_rpc_jwt: Option<String>, /* private fields */
}
OP Stack Configuration

Defaults

All configuration values have a default, documented in the fields section below. Config::default() returns the default values for the default profile while Config::with_root() returns the values based on the given directory. Config::load() starts with the default profile and merges various providers into the config, same for Config::load_with_root(), but there the default values are determined by Config::with_root()

Provider Details

Config is a Figment Provider with the following characteristics:

  • Profile

    The profile is set to the value of the profile field.

  • Metadata

    This provider is named OP Stack Config. It does not specify a Source and uses default interpolation.

  • Data

    The data emitted by this provider are the keys and values corresponding to the fields and values of the structure. The dictionary is emitted to the “default” meta-profile.

Note that these behaviors differ from those of Config::figment().

Fields

profile: Profile

The selected profile. (default: default default)

Note: This field is never serialized nor deserialized. When a Config is merged into a Figment as a Provider, this profile is selected on the Figment. When a Config is extracted, this field is set to the extracting Figment’s selected Profile.

artifacts: PathBuf

The path to the op stack artifact directory. (default: default .stack)

monorepo: MonorepoConfig

The Optimism Monorepo configuration options.

l1_client: L1Client

The type of L1 Client to use. (default: default L1Client::Geth)

l2_client: L2Client

The type of L2 Client to use. (default: default L2Client::OpGeth)

rollup_client: RollupClient

The type of Rollup Client to use. (default: default RollupClient::OpNode)

l1_client_url: Option<String>

The L1 Client base URL.

l1_client_port: Option<u16>

The L1 Client port.

l2_client_url: Option<String>

The L2 Client URL.

l2_client_port: Option<u16>

The L2 Client port.

rollup_client_url: Option<String>

The rollup client URL.

rollup_client_port: Option<u16>

The rollup client port.

deployer: Option<String>

Deployer is the contract deployer. By default, this is a hardhat test account.

challenger: ChallengerAgent

The challenger agent to use. (default: default ChallengerAgent::OpChallengerGo)

enable_sequencing: bool

Enable Sequencing. (default: default false)

enable_fault_proofs: bool

Enable Fault Proofs. (default: default false)

eth_rpc_jwt: Option<String>

Stack Stage Components

This is a table array of [StageConfig]s, each of which represents a stage in the stack and is orchestrated by the [StageManager].

The parsing of [StageConfig]s is done by the [StageConfig::from_toml] function. This allows for different configuration formats to be used for each stage. JWT secret that should be used for any rpc calls

Implementations

Source

impl Config<'_>

pub const DEFAULT_PROFILE: Profile

The default profile: “default”

pub const PROFILE_SECTION: &'static str = "profile"

TOML section for profiles

pub const FILE_NAME: &'static str = "stack.toml"

File name of config toml file

pub const STACK_DIR_NAME: &'static str = ".stack"

The name of the directory rollup reserves for itself under the user’s home directory: ~

pub const STANDALONE_SECTIONS: &'static [&'static str]

Standalone sections in the config which get integrated into the selected profile

pub fn load() -> Self

Returns the current Config

See Config::figment

pub fn load_with_root(root: impl Into<PathBuf>) -> Self

Returns the current Config

See Config::figment_with_root

pub fn from_provider<T: Provider>(provider: T) -> Self

Extract a Config from provider, panicking if extraction fails.

Panics

If extraction fails, prints an error message indicating the failure and panics. For a version that doesn’t panic, use Config::try_from().

Example
use op_config::Config;
use figment::providers::{Toml, Format, Env};

// Use default `Figment`, but allow values from `other.toml`
// to supersede its values.
let figment = Config::figment()
    .merge(Toml::file("other.toml").nested());

let config = Config::from_provider(figment);
pub fn from_toml(path: impl Into<PathBuf>) -> Result<Self, ExtractConfigError>

Attempts to build a Config using a PathBuf toml file. If the file does not exist, it will be created with default values.

pub fn try_from<T: Provider>(provider: T) -> Result<Self, ExtractConfigError>

Attempts to extract a Config from provider, returning the result.

Example
use op_config::Config;
use figment::providers::{Toml, Format, Env};

// Use default `Figment`, but allow values from `other.toml`
// to supersede its values.
let figment = Config::figment()
    .merge(Toml::file("other.toml").nested());

let config = Config::try_from(figment);
pub fn figment() -> Figment

Returns the default figment

The default figment reads from the following sources, in ascending priority order:

  1. Config::default() (see defaults)
  2. stack.toml or filename in OP_STACK_CONFIG environment variable
  3. OP_STACK_ prefixed environment variables

The profile selected is the value set in the OP_STACK_PROFILE environment variable. If it is not set, it defaults to default.

Example
use op_config::Config;
use serde::Deserialize;

let my_config = Config::figment().extract::<Config>();
pub fn figment_with_root(root: impl Into<PathBuf>) -> Figment

Returns the default figment enhanced with additional context extracted from the provided root, like remappings and directories.

Example
use op_config::Config;
use serde::Deserialize;

let my_config = Config::figment_with_root(".").extract::<Config>();
pub fn with_root(root: impl Into<PathBuf>) -> Self

Creates a new Config that adds additional context extracted from the provided root.

Example
use op_config::Config;
let my_config = Config::with_root(".");
pub fn create_artifacts_dir(&self) -> Result<()>

Creates the artifacts directory if it doesn’t exist.

pub fn selected_profile() -> Profile

Returns the selected profile

If the STACK_PROFILE env variable is not set, this returns the DEFAULT_PROFILE

pub fn stack_dir_toml() -> Option<PathBuf>

Returns the path to the global toml file that’s stored at ~/.stack/stack.toml

pub fn stack_dir() -> Option<PathBuf>

Returns the path to the config dir ~/.stack/

pub fn force_overwrites(self, force: bool) -> Self

Force monorepo artifact overwrites.

pub fn set_l1_client(&mut self) -> Result<()>

Sets the l1 client to use via a cli prompt.

pub fn set_l2_client(&mut self) -> Result<()>

Sets the l2 client to use via a cli prompt.

pub fn set_rollup_client(&mut self) -> Result<()>

Sets the rollup client to use via a cli prompt.

pub fn set_challenger(&mut self) -> Result<()>

Sets the challenger agent to use via a cli prompt.